/*!
 * \file ci.h
 *
 * \author FTDI
 * \date 20120114
 *
 * Copyright  2011 Future Technology Devices International Limited
 * Company Confidential
 *
 * Project: FT12x
 * Module: LPC1114-FT12x Eval
 *
 * Rivision History:
 * 0.1 - initial version
 */

#ifndef __CI_H__
#define __CI_H__

#define FT12X_NOLAZYCLOCK			0x02
#define FT12X_CLOCKRUNNING        0x04
#define FT12X_INTERRUPTMODE		0x08
#define FT12X_SOFTCONNECT			0x10
#define FT12X_ENDP_NONISO			0x00
#define FT12X_ENDP_ISOOUT			0x40
#define FT12X_ENDP_ISOIN			0x80
#define FT12X_ENDP_ISOIO			0xC0

#define FT12X_CLOCK_12M			0x03
#define FT12X_CLOCK_4M			0x0b
#define FT12X_SETTOONE            0x40
#define FT12X_SOFONLY				0x80

#define FT12X_DMASINGLE			0x00
#define FT12X_BURST_4				0x01
#define FT12X_BURST_8				0x02
#define FT12X_BURST_16			0x03
#define FT12X_DMAENABLE           0x04
#define FT12X_DMA_INTOKEN			0x08
#define FT12X_AUTOLOAD			0x10
#define FT12X_NORMALPLUSSOF		0x20
#define FT12X_ENDP4INTENABLE		0x40
#define FT12X_ENDP5INTENABLE		0x80

#define FT12X_INT_ENDP0OUT		0x01
#define FT12X_INT_ENDP0IN			0x02
#define FT12X_INT_ENDP1OUT		0x04
#define FT12X_INT_ENDP1IN			0x08
#define FT12X_INT_ENDP2OUT		0x10
#define FT12X_INT_ENDP2IN			0x20
#define FT12X_INT_ENDP3OUT		0x0100
#define FT12X_INT_ENDP3IN			0x0200
#define FT12X_INT_ENDP4OUT		0x0400
#define FT12X_INT_ENDP4IN			0x0800
#define FT12X_INT_ENDP5OUT		0x1000
#define FT12X_INT_ENDP5IN			0x2000
#define FT12X_INT_ENDP6OUT		0x4000
#define FT12X_INT_ENDP6IN			0x8000


#define FT12X_INT_BUSRESET		0x40
#define FT12X_INT_SUSPENDCHANGE	0x80
#define FT12X_INT_EOT				0x0100

#define FT12X_SETUPPACKET			0x20

#define FT12X_BUFFER0FULL			0x20
#define FT12X_BUFFER1FULL			0x40

#define FT12X_FULLEMPTY			0x01
#define FT12X_STALL				0x02

#define ID_CHIP					0xFD
#define ID_VENDOR				0xEA
#define ID_PRODUCT				0xEB
#define ID_FTDI					0xED

void FT12x_SetAddressEnable(unsigned char bAddress, unsigned char bEnable);
void FT12x_SetEndpointEnable(unsigned char bEnable);
void FT12x_SetMode(unsigned char bConfig, unsigned char bClkDiv);
void FT12x_SetDMA(unsigned char bMode);
unsigned int FT12x_ReadInterruptRegister(void);
unsigned char FT12x_SelectEndpoint(unsigned char bEndp);
unsigned char FT12x_ReadLastTransactionStatus(unsigned char bEndp);
unsigned char FT12x_ReadEndpointStatus(unsigned char bEndp);
void FT12x_SetEndpointStatus(unsigned char bEndp, unsigned char bStalled);
void FT12x_SendResume(void);
unsigned short FT12x_ReadCurrentFrameNumber(void);
unsigned short FT12x_ReadChipID(void);

unsigned char FT12x_ReadEndpoint(unsigned char endp, unsigned char * buf, unsigned char len);
unsigned char FT12x_WriteEndpoint(unsigned char endp, unsigned char * buf, unsigned char len);
void FT12x_AcknowledgeEndpoint(unsigned char endp);

unsigned char FT12x_ReadMainEndpoint(unsigned char * buf); // V2.2

unsigned char FT12x_inportb(void);
void FT12x_outportb(unsigned char val, unsigned char mask);
void FT12x_SetEndpointConfig(unsigned char bEndp,unsigned char enable, unsigned char type, unsigned char size);


#endif	/* __CI_H__ */
